@@ -112,12 +112,16 @@ INFRASTRUCTURE_TYPE_OV = [
     "anonymization",
     "botnet",
     "command-and-control",
+    "control-system",
     "exfiltration",
+    "firewall",
     "hosting-malware",
     "hosting-target-lists",
     "phishing",
     "reconnaissance",
+    "routers-switches",
     "staging",
+    "workstation",
     "unknown",
 ]
 MALWARE_RESULT_OV = [
@@ -2041,7 +2045,7 @@ TIMESTAMP_COMPARE = {
         ('stop_time', 'gt', 'start_time'),
     ],
     "sighting": [
-        ('last_seen', 'gt', 'first_seen'),
+        ('last_seen', 'ge', 'first_seen'),
     ],
     'threat-actor': [
         ('last_seen', 'ge', 'first_seen')
@@ -2051,7 +2055,7 @@ TIMESTAMP_COMPARE = {
 # Mapping of STIX Object timestamp properties with a comparison requirement
 TIMESTAMP_COMPARE_OBSERVABLE = {
     "network-traffic": [
-        ('end', 'gt', 'start'),
+        ('end', 'ge', 'start'),
     ],
 }
 
